==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:04.666Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef")
@software.amazon.jsii.Jsii.Proxy(CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef extends software.amazon.jsii.JsiiSerializable {

    /**
     * A Cloud Secret Manager secret version. Must be 'latest' for the latest version or an integer for a specific version.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#key CloudRunService#key}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * The name of the secret in Cloud Secret Manager.
     * <p>
     * By default, the secret is assumed to be in the same project.
     * If the secret is in another project, you must define an alias.
     * An alias definition has the form: :projects/&lt;project-id|project-number&gt;/secrets/.
     * If multiple alias definitions are needed, they must be separated by commas.
     * The alias definitions must be set on the run.googleapis.com/secrets annotation.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#name CloudRunService#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * @return a {@link Builder} of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef> {
        java.lang.String key;
        java.lang.String name;

        /**
         * Sets the value of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef#getKey}
         * @param key A Cloud Secret Manager secret version. Must be 'latest' for the latest version or an integer for a specific version. This parameter is required.
         *            Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#key CloudRunService#key}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef#getName}
         * @param name The name of the secret in Cloud Secret Manager. This parameter is required.
         *             By default, the secret is assumed to be in the same project.
         *             If the secret is in another project, you must define an alias.
         *             An alias definition has the form: :projects/&lt;project-id|project-number&gt;/secrets/.
         *             If multiple alias definitions are needed, they must be separated by commas.
         *             The alias definitions must be set on the run.googleapis.com/secrets annotation.
         *             <p>
         *             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#name CloudRunService#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef {
        private final java.lang.String key;
        private final java.lang.String name;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(builder.key, "key is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("name", om.valueToTree(this.getName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy that = (CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            return this.name.equals(that.name);
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.name.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:21.087Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef")
@software.amazon.jsii.Jsii.Proxy(CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef extends software.amazon.jsii.JsiiSerializable {

    /**
     * A Cloud Secret Manager secret version. Must be 'latest' for the latest version or an integer for a specific version.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#key CloudRunService#key}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getKey();

    /**
     * The name of the secret in Cloud Secret Manager.
     * <p>
     * By default, the secret is assumed to be in the same project.
     * If the secret is in another project, you must define an alias.
     * An alias definition has the form: :projects/{project-id|project-number}/secrets/.
     * If multiple alias definitions are needed, they must be separated by commas.
     * The alias definitions must be set on the run.googleapis.com/secrets annotation.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#name CloudRunService#name}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * @return a {@link Builder} of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef> {
        java.lang.String key;
        java.lang.String name;

        /**
         * Sets the value of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef#getKey}
         * @param key A Cloud Secret Manager secret version. Must be 'latest' for the latest version or an integer for a specific version. This parameter is required.
         *            Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#key CloudRunService#key}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder key(java.lang.String key) {
            this.key = key;
            return this;
        }

        /**
         * Sets the value of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef#getName}
         * @param name The name of the secret in Cloud Secret Manager. This parameter is required.
         *             By default, the secret is assumed to be in the same project.
         *             If the secret is in another project, you must define an alias.
         *             An alias definition has the form: :projects/{project-id|project-number}/secrets/.
         *             If multiple alias definitions are needed, they must be separated by commas.
         *             The alias definitions must be set on the run.googleapis.com/secrets annotation.
         *             <p>
         *             Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/cloud_run_service#name CloudRunService#name}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef {
        private final java.lang.String key;
        private final java.lang.String name;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.key = software.amazon.jsii.Kernel.get(this, "key", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.key = java.util.Objects.requireNonNull(builder.key, "key is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
        }

        @Override
        public final java.lang.String getKey() {
            return this.key;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("key", om.valueToTree(this.getKey()));
            data.set("name", om.valueToTree(this.getName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy that = (CloudRunServiceTemplateSpecContainersEnvValueFromSecretKeyRef.Jsii$Proxy) o;

            if (!key.equals(that.key)) return false;
            return this.name.equals(that.name);
        }

        @Override
        public final int hashCode() {
            int result = this.key.hashCode();
            result = 31 * result + (this.name.hashCode());
            return result;
        }
    }
}
